@@ -1,17 +1,16 @@
 import glob
 from launchable.utils.authentication import get_org_workspace
-from launchable.commands.record.build import build
 import os
 import traceback
 import click
 from junitparser import JUnitXml, TestSuite, TestCase  # type: ignore
 import xml.etree.ElementTree as ET
-from typing import Callable, Dict, Generator,  List, Optional
+from typing import Callable, Dict, Generator, List, Optional
 from more_itertools import ichunked
 from .case_event import CaseEvent, CaseEventType
 from ...utils.http_client import LaunchableClient
 from ...utils.env_keys import REPORT_ERROR_KEY
-from ...utils.session import parse_session
+from ...utils.session import parse_session, read_build
 from ...testpath import TestPathComponent, FilePathNormalizer
 from ..helper import find_or_create_session
 from http import HTTPStatus
@@ -41,7 +40,8 @@ from tabulate import tabulate
     'build_name',
     help='build name',
     type=str,
-    metavar='BUILD_NAME'
+    metavar='BUILD_NAME',
+    hidden=True,
 )
 @click.option(
     '--subset-id',
@@ -91,8 +91,8 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
     else:
         session_id = find_or_create_session(
             context, session, build_name, flavor)
-
-        record_start_at = get_record_start_at(build_name, session)
+        build_name = read_build()
+        record_start_at = get_record_start_at(session_id)
 
     logger = Logger()
 
@@ -165,7 +165,7 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
         def check_timestamp(self, enable: bool):
             self._check_timestamp = enable
 
-        def __init__(self):
+        def __init__(self, dry_run=False):
             self.reports = []
             self.skipped_reports = []
             self.path_builder = CaseEvent.default_path_builder(
@@ -173,6 +173,7 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
             self.junitxml_parse_func = None
             self.check_timestamp = True
             self.base_path = base_path
+            self.dry_run = dry_run
 
         def make_file_path_component(self, filepath) -> TestPathComponent:
             """Create a single TestPathComponent from the given file path"""
@@ -205,7 +206,8 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
 
         def run(self):
             count = 0  # count number of test cases sent
-            client = LaunchableClient(test_runner=context.invoked_subcommand)
+            client = LaunchableClient(test_runner=context.invoked_subcommand,
+                                      dry_run=context.obj.dry_run)
 
             def testcases(reports: List[str]) -> Generator[CaseEventType, None, None]:
                 exceptions = []
@@ -324,7 +326,7 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
             click.echo(
                 "\nRun `launchable inspect tests --test-session-id {}` to view uploaded test results".format(test_session_id))
 
-    context.obj = RecordTests()
+    context.obj = RecordTests(dry_run=context.obj.dry_run)
 
 
 # if we fail to determine the timestamp of the build, we err on the side of collecting more test reports
@@ -332,7 +334,7 @@ def tests(context, base_path: str, session: Optional[str], build_name: Optional[
 INVALID_TIMESTAMP = datetime.datetime.fromtimestamp(0)
 
 
-def get_record_start_at(build_name: Optional[str], session: Optional[str]):
+def get_record_start_at(session: Optional[str]):
     """
     Determine the baseline timestamp to be used for up-to-date checks of report files.
     Only files newer than this timestamp will be collected.
@@ -340,7 +342,7 @@ def get_record_start_at(build_name: Optional[str], session: Optional[str]):
     Based on the thinking that if a build doesn't exist tests couldn't have possibly run, we attempt
     to use the timestamp of a build, with appropriate fallback.
     """
-    if session is None and build_name is None:
+    if session is None:
         raise click.UsageError(
             'Either --build or --session has to be specified')
 
