@@ -19,9 +19,22 @@ def get_base_url():
     return os.getenv(BASE_URL_KEY) or DEFAULT_BASE_URL
 
 
+class DryRunResponse:
+    def __init__(self, status_code, payload):
+        self.status_code = status_code
+        self.payload = payload
+
+    def raise_for_status(self):
+        return
+
+    def json(self):
+        return self.payload
+
+
 class LaunchableClient:
-    def __init__(self, base_url: str = "", session: Session = None, test_runner: str = ""):
+    def __init__(self, base_url: str = "", session: Session = None, test_runner: str = "", dry_run: bool = False):
         self.base_url = base_url or get_base_url()
+        self.dry_run = dry_run
 
         if session is None:
             strategy = Retry(
@@ -51,7 +64,15 @@ class LaunchableClient:
 
         headers = self._headers(compress)
 
-        Logger().audit(AUDIT_LOG_FORMAT.format(method, url, headers, payload))
+        Logger().audit(AUDIT_LOG_FORMAT.format(
+            "(DRY RUN) " if self.dry_run else "", method, url, headers, payload))
+
+        if self.dry_run and method.upper() not in ["HEAD", "GET"]:
+            return DryRunResponse(status_code=200, payload={
+                "id": "dry-run-session",  # `record session` use this
+                "testPaths": [],  # `split_subset` use this
+                "rest": [],  # `split_subset` use this
+            })
 
         data = _build_data(payload, compress)
 
