@@ -63,7 +63,8 @@ class MavenTest(CliTestCase):
                           'maven', str(self.test_files_dir) + "/**/reports")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
+        payload = json.loads(gzip.decompress(
+            responses.calls[1].request.body).decode())
 
         for e in payload["events"]:
             del e["created_at"]
